@@ -74,12 +74,12 @@ Tellico::Data::FieldPtr Collection::createDefaultField(DefaultField fieldEnum) {
 }
 
 Collection::Collection(const QString& title_)
-    : QObject(), QSharedData(), m_nextEntryId(0), m_title(title_), m_trackGroups(false) {
+    : QObject(), QSharedData(), m_nextEntryId(1), m_title(title_), m_trackGroups(false) {
   m_id = getID();
 }
 
 Collection::Collection(bool addDefaultFields_, const QString& title_)
-    : QObject(), QSharedData(), m_nextEntryId(0), m_title(title_), m_trackGroups(false) {
+    : QObject(), QSharedData(), m_nextEntryId(1), m_title(title_), m_trackGroups(false) {
   if(m_title.isEmpty()) {
     m_title = i18n("My Collection");
   }
@@ -380,7 +380,7 @@ bool Collection::modifyField(Tellico::Data::FieldPtr newField_) {
   }
 
   if(resetGroups) {
-    myLog() << "invalidating groups";
+//    myLog() << "invalidating groups";
     invalidateGroups();
   }
 
@@ -485,14 +485,14 @@ void Collection::addEntries(const Tellico::Data::EntryList& entries_) {
     }
 
     m_entries.append(entry);
-//  myDebug() << "added entry (" << entry->title() << ")";
+//    myDebug() << "added entry (" << entry->title() << ")" <<  entry->id();
 
     if(entry->id() >= m_nextEntryId) {
       m_nextEntryId = entry->id() + 1;
     } else if(entry->id() == -1) {
       entry->setId(m_nextEntryId);
       ++m_nextEntryId;
-    } else if(m_entryById.value(entry->id())) {
+    } else if(m_entryById.contains(entry->id())) {
       if(!foster) {
         myDebug() << "the collection already has an entry with id = " << entry->id();
       }
@@ -514,17 +514,18 @@ void Collection::addEntries(const Tellico::Data::EntryList& entries_) {
 }
 
 void Collection::removeEntriesFromDicts(const Tellico::Data::EntryList& entries_, const QStringList& fields_) {
-  QList<EntryGroup*> modifiedGroups;
+  QSet<EntryGroup*> modifiedGroups;
   foreach(EntryPtr entry, entries_) {
     // need a copy of the vector since it gets changed
     QList<EntryGroup*> groups = entry->groups();
     foreach(EntryGroup* group, groups) {
       // only clear groups for the modified fields, skip the others
-      if(!fields_.contains(group->fieldName()))  {
+      // also clear for all derived values, just in case
+      if(!fields_.contains(group->fieldName()) && hasField(group->fieldName()) && !fieldByName(group->fieldName())->hasFlag(Field::Derived))  {
         continue;
       }
-      if(entry->removeFromGroup(group) && !modifiedGroups.contains(group)) {
-        modifiedGroups.append(group);
+      if(entry->removeFromGroup(group)) {
+        modifiedGroups.insert(group);
       }
       if(group->isEmpty() && !m_groupsToDelete.contains(group)) {
         m_groupsToDelete.push_back(group);
@@ -532,7 +533,7 @@ void Collection::removeEntriesFromDicts(const Tellico::Data::EntryList& entries_
     }
   }
   if(!modifiedGroups.isEmpty()) {
-    emit signalGroupsModified(CollPtr(this), modifiedGroups);
+    emit signalGroupsModified(CollPtr(this), modifiedGroups.toList());
   }
 }
 
@@ -545,7 +546,7 @@ void Collection::updateDicts(const Tellico::Data::EntryList& entries_, const QSt
   }
   QStringList modifiedFields = fields_;
   if(modifiedFields.isEmpty()) {
-    myDebug() << "updating all fields";
+//    myDebug() << "updating all fields";
     modifiedFields = fieldNames();
   }
   removeEntriesFromDicts(entries_, modifiedFields);
@@ -681,9 +682,10 @@ Tellico::Data::EntryGroupDict* Collection::entryGroupDictByName(const QString& n
 
 void Collection::populateDict(Tellico::Data::EntryGroupDict* dict_, const QString& fieldName_, const Tellico::Data::EntryList& entries_) {
 //  myDebug() << fieldName_;
+  Q_ASSERT(dict_);
   const bool isBool = hasField(fieldName_) && fieldByName(fieldName_)->type() == Field::Bool;
 
-  QList<EntryGroup*> modifiedGroups;
+  QSet<EntryGroup*> modifiedGroups;
   foreach(EntryPtr entry, entries_) {
     const QStringList groups = entryGroupNamesByField(entry, fieldName_);
     foreach(QString groupTitle, groups) { // krazy:exclude=foreach
@@ -692,23 +694,23 @@ void Collection::populateDict(Tellico::Data::EntryGroupDict* dict_, const QStrin
       if(isBool && !groupTitle.isEmpty()) {
         groupTitle = fieldTitleByName(fieldName_);
       }
-      EntryGroup* group = (*dict_).value(groupTitle);
+      EntryGroup* group = dict_->value(groupTitle);
       // if the group doesn't exist, create it
       if(!group) {
         group = new EntryGroup(groupTitle, fieldName_);
         dict_->insert(groupTitle, group);
       } else if(group->isEmpty()) {
-        // if it's empty, then it was added to the vector of groups to delete
+        // if it's empty, then it was previously added to the vector of groups to delete
         // remove it from that vector now that we're adding to it
-        m_groupsToDelete.removeAll(group);
+        m_groupsToDelete.removeOne(group);
       }
       if(entry->addToGroup(group)) {
-        modifiedGroups.push_back(group);
+        modifiedGroups.insert(group);
       }
     } // end group loop
   } // end entry loop
   if(!modifiedGroups.isEmpty()) {
-    emit signalGroupsModified(CollPtr(this), modifiedGroups);
+    emit signalGroupsModified(CollPtr(this), modifiedGroups.toList());
   }
 }
 
@@ -762,13 +764,14 @@ QStringList Collection::entryGroupNamesByField(Tellico::Data::EntryPtr entry_, c
   bool allEmpty = true;
   StringSet values;
   foreach(FieldPtr field, m_peopleFields) {
-    QStringList groups = entry_->groupNamesByFieldName(field->name());
-    if(groups.count() != 1 || !groups.at(0).isEmpty()) {
+    const QStringList groups = entry_->groupNamesByFieldName(field->name());
+    if(allEmpty && (groups.count() != 1 || !groups.at(0).isEmpty())) {
       allEmpty = false;
     }
     values.add(groups);
   }
   if(!allEmpty) {
+    // we don't want the empty string
     values.remove(QString());
   }
   return values.toList();
