@@ -109,6 +109,7 @@ Tellico::Data::EntryList Controller::visibleEntries() {
 }
 
 void Controller::slotCollectionAdded(Tellico::Data::CollPtr coll_) {
+  MARK;
   // at start-up, this might get called too early, so check and bail
   if(!m_mainWindow->m_groupView) {
     return;
@@ -445,6 +446,7 @@ void Controller::slotCopySelectedEntries() {
     entries.append(Data::EntryPtr(new Data::Entry(*it)));
   }
   Kernel::self()->addEntries(entries, false);
+  m_widgetWithSelection = 0; // KDE bug 231125: probably should figure out how to really fix it...
   slotUpdateSelection(0, old);
 }
 
