@@ -114,6 +114,7 @@ bool Document::newDocument(int type_) {
 }
 
 bool Document::openDocument(const KUrl& url_) {
+  MARK;
   m_loadAllImages = false;
   // delayed image loading only works for local files
   if(!url_.isLocalFile()) {
@@ -648,8 +649,7 @@ bool Document::mergeEntry(Data::EntryPtr e1, Data::EntryPtr e2, bool overwrite_,
     return false;
   }
   bool ret = true;
-  FieldList fields = e1->collection()->fields();
-  foreach(FieldPtr field, fields) {
+  foreach(FieldPtr field, e1->collection()->fields()) {
     if(e2->field(field).isEmpty()) {
       continue;
     }
