@@ -82,7 +82,7 @@ private:
   virtual FetchRequest updateRequest(Data::EntryPtr entry);
   virtual void resetSearch();
   virtual KUrl searchUrl();
-  virtual void parseData(const QByteArray& data);
+  virtual void parseData(QByteArray& data);
   virtual Data::EntryPtr fetchEntryHookData(Data::EntryPtr entry);
 
   int m_start;
