@@ -71,7 +71,13 @@ enum Type {
   WineCom,
   TheMovieDB,
   MusicBrainz,
-  GiantBomb
+  GiantBomb,
+  OpenLibrary,
+  Multiple,
+  Freebase,
+  DVDFr,
+  Filmaster,
+  Douban
 };
 
   }
