@@ -89,6 +89,7 @@ void Manager::registerFunction(int type_, const FetcherFunction& func_) {
 
 void Manager::loadFetchers() {
   m_fetchers.clear();
+  m_uuidHash.clear();
 
   KSharedConfigPtr config = KGlobal::config();
   if(config->hasGroup(QLatin1String("Data Sources"))) {
@@ -100,6 +101,7 @@ void Manager::loadFetchers() {
       if(f) {
         m_fetchers.append(f);
         f->setMessageHandler(m_messager);
+        m_uuidHash.insert(f->uuid(), f);
       }
     }
     m_loadDefaults = false;
@@ -119,6 +121,10 @@ Tellico::Fetch::FetcherVec Manager::fetchers(int type_) {
   return vec;
 }
 
+Tellico::Fetch::Fetcher::Ptr Manager::fetcherByUuid(const QString& uuid_) {
+  return m_uuidHash.contains(uuid_) ? m_uuidHash[uuid_] : Fetcher::Ptr();
+}
+
 Tellico::Fetch::KeyMap Manager::keyMap(const QString& source_) const {
   // an empty string means return all
   if(source_.isEmpty()) {
@@ -139,7 +145,7 @@ Tellico::Fetch::KeyMap Manager::keyMap(const QString& source_) const {
   }
 
   KeyMap map;
-  for(KeyMap::ConstIterator it = m_keyMap.begin(); it != m_keyMap.end(); ++it) {
+  for(KeyMap::ConstIterator it = m_keyMap.constBegin(); it != m_keyMap.constEnd(); ++it) {
     if(foundFetcher->canSearch(it.key())) {
       map.insert(it.key(), it.value());
     }
@@ -270,7 +276,7 @@ Tellico::Fetch::FetcherVec Manager::defaultFetchers() {
 #endif
   vec.append(SRUFetcher::libraryOfCongress(this));
   FETCHER_ADD(ISBNdb);
-  FETCHER_ADD(Yahoo);
+//  FETCHER_ADD(Yahoo);
   FETCHER_ADD(AnimeNfo);
   FETCHER_ADD(Arxiv);
   FETCHER_ADD(GoogleScholar);
@@ -281,6 +287,13 @@ Tellico::Fetch::FetcherVec Manager::defaultFetchers() {
   if(KGlobal::locale()->languageList().contains(QLatin1String("it"))) {
     FETCHER_ADD(IBS);
   }
+#ifdef HAVE_QJSON
+  FETCHER_ADD(OpenLibrary);
+  FETCHER_ADD(Freebase);
+#endif
+  if(KGlobal::locale()->languageList().contains(QLatin1String("fr"))) {
+    FETCHER_ADD(DVDFr);
+  }
   return vec;
 }
 
@@ -415,7 +428,7 @@ QString Manager::typeName(Tellico::Fetch::Type type_) {
 QPixmap Manager::fetcherIcon(Tellico::Fetch::Fetcher::Ptr fetcher_, int group_, int size_) {
 #ifdef HAVE_YAZ
   if(fetcher_->type() == Fetch::Z3950) {
-    Fetch::Z3950Fetcher* f = static_cast<const Fetch::Z3950Fetcher*>(fetcher_.data());
+    const Fetch::Z3950Fetcher* f = static_cast<const Fetch::Z3950Fetcher*>(fetcher_.data());
     KUrl u;
     u.setProtocol(QLatin1String("http"));
     u.setHost(f->host());
@@ -429,15 +442,15 @@ QPixmap Manager::fetcherIcon(Tellico::Fetch::Fetcher::Ptr fetcher_, int group_,
     const Fetch::ExecExternalFetcher* f = static_cast<const Fetch::ExecExternalFetcher*>(fetcher_.data());
     const QString p = f->execPath();
     KUrl u;
-    if(p.indexOf(QLatin1String("allocine")) > -1) {
+    if(p.contains(QLatin1String("allocine"))) {
       u = QLatin1String("http://www.allocine.fr");
-    } else if(p.indexOf(QLatin1String("ministerio_de_cultura")) > -1) {
+    } else if(p.contains(QLatin1String("ministerio_de_cultura"))) {
       u = QLatin1String("http://www.mcu.es");
-    } else if(p.indexOf(QLatin1String("dark_horse_comics")) > -1) {
+    } else if(p.contains(QLatin1String("dark_horse_comics"))) {
       u = QLatin1String("http://www.darkhorse.com");
-    } else if(p.indexOf(QLatin1String("boardgamegeek")) > -1) {
+    } else if(p.contains(QLatin1String("boardgamegeek"))) {
       u = QLatin1String("http://www.boardgamegeek.com");
-    } else if(f->source().indexOf(QLatin1String("amarok"), 0, Qt::CaseInsensitive) > -1) {
+    } else if(f->source().contains(QLatin1String("amarok"), Qt::CaseInsensitive)) {
       return LOAD_ICON(QLatin1String("amarok"), group_, size_);
     }
     if(!u.isEmpty() && u.isValid()) {
@@ -447,7 +460,7 @@ QPixmap Manager::fetcherIcon(Tellico::Fetch::Fetcher::Ptr fetcher_, int group_,
       }
     }
   }
-  return fetcherIcon(fetcher_->type(), group_);
+  return fetcherIcon(fetcher_->type(), group_, size_);
 }
 
 QPixmap Manager::fetcherIcon(Tellico::Fetch::Type type_, int group_, int size_) {
@@ -458,7 +471,17 @@ QPixmap Manager::fetcherIcon(Tellico::Fetch::Type type_, int group_, int size_)
     myWarning() << "no pixmap defined for type =" << type_;
   }
 
-  return name.isEmpty() ? QPixmap() : LOAD_ICON(name, group_, size_);
+  if(name.isEmpty()) {
+    return QPixmap();
+  }
+
+  QPixmap pix = KIconLoader::global()->loadIcon(name, static_cast<KIconLoader::Group>(group_),
+                                                size_, KIconLoader::DefaultState,
+                                                QStringList(), 0L, true);
+  if(pix.isNull()) {
+    pix = BarIcon(name);
+  }
+  return pix;
 }
 
 Tellico::StringHash Manager::optionalFields(Type type_) {
