@@ -140,6 +140,9 @@ void IMDBFetcher::search() {
   m_url.setHost(m_host.isEmpty() ? QLatin1String(IMDB_SERVER) : m_host);
   m_url.setPath(QLatin1String("/find"));
 
+  // as far as I can tell, the url encoding should always be iso-8859-1?
+  m_url.addQueryItem(QLatin1String("q"), request().value);
+
   switch(request().key) {
     case Title:
       m_url.addQueryItem(QLatin1String("s"), QLatin1String("tt"));
@@ -149,15 +152,16 @@ void IMDBFetcher::search() {
       m_url.addQueryItem(QLatin1String("s"), QLatin1String("nm"));
       break;
 
+    case Raw:
+      m_url = request().value;
+      break;
+
     default:
-      myWarning() << "FetchKey not supported";
+      myWarning() << "not supported:" << request().key;
       stop();
       return;
   }
 
-  // as far as I can tell, the url encoding should always be iso-8859-1?
-  m_url.addQueryItem(QLatin1String("q"), request().value);
-
 //  myDebug() << "url =" << m_url;
 #endif
 
@@ -187,7 +191,12 @@ void IMDBFetcher::continueSearch() {
 
   if(m_currentTitleBlock == Partial) {
     parseTitleBlock(m_partialTitles);
-    m_currentTitleBlock = m_countOffset == 0 ? Unknown : Partial;
+    m_currentTitleBlock = m_countOffset == 0 ? Approx : Partial;
+  }
+
+  if(m_currentTitleBlock == Approx) {
+    parseTitleBlock(m_approxTitles);
+    m_currentTitleBlock = m_countOffset == 0 ? Unknown : Approx;
   }
 
   if(m_currentTitleBlock == SinglePerson) {
@@ -215,6 +224,9 @@ void IMDBFetcher::stop() {
 
 void IMDBFetcher::slotRedirection(KIO::Job*, const KUrl& toURL_) {
   m_url = toURL_;
+  if(m_url.path().contains(QRegExp(QLatin1String("/tt\\d+/$"))))  {
+    m_url.setPath(m_url.path() + QLatin1String("combined"));
+  }
   m_redirected = true;
 }
 
@@ -227,6 +239,7 @@ void IMDBFetcher::slotComplete(KJob*) {
 
   m_text = Tellico::fromHtmlData(m_job->data());
   if(m_text.isEmpty()) {
+    myLog() << "No data returned";
     stop();
     return;
   }
@@ -245,23 +258,34 @@ void IMDBFetcher::slotComplete(KJob*) {
   m_job = 0;
 
   // a single result was found if we got redirected
-  if(request().key == Title) {
-    if(m_redirected) {
+  switch(request().key) {
+    case Title:
+      if(m_redirected) {
+        parseSingleTitleResult();
+      } else {
+        parseMultipleTitleResults();
+      }
+      break;
+
+    case Person:
+      if(m_redirected) {
+        parseSingleNameResult();
+      } else {
+        parseMultipleNameResults();
+      }
+      break;
+
+    case Raw:
       parseSingleTitleResult();
-    } else {
-      parseMultipleTitleResults();
-    }
-  } else {
-    if(m_redirected) {
-      parseSingleNameResult();
-    } else {
-      parseMultipleNameResults();
-    }
+      break;
+
+    default:
+      myWarning() << "skipping results";
+      break;
   }
 }
 
 void IMDBFetcher::parseSingleTitleResult() {
-//  DEBUG_LINE
   s_titleRx->indexIn(Tellico::decodeHTML(m_text));
   // split title at parenthesis
   const QString cap1 = s_titleRx->cap(1);
@@ -270,7 +294,11 @@ void IMDBFetcher::parseSingleTitleResult() {
   FetchResult* r = new FetchResult(Fetcher::Ptr(this),
                                    pPos == -1 ? cap1 : cap1.left(pPos),
                                    pPos == -1 ? QString() : cap1.mid(pPos));
-  m_matches.insert(r->uid, m_url);
+  // IMDB returns different HTML for single title results and has a query in the url
+  // clear the query so we download the "canonical" page for the title
+  KUrl url(m_url);
+  url.setEncodedQuery(QByteArray());
+  m_matches.insert(r->uid, url);
   emit signalResultFound(r);
 
   m_hasMoreResults = false;
@@ -278,7 +306,6 @@ void IMDBFetcher::parseSingleTitleResult() {
 }
 
 void IMDBFetcher::parseMultipleTitleResults() {
-//  DEBUG_LINE;
   QString output = Tellico::decodeHTML(m_text);
 
   // IMDb can return three title lists, popular, exact, and partial
@@ -286,13 +313,19 @@ void IMDBFetcher::parseMultipleTitleResults() {
   int pos_popular = output.indexOf(QLatin1String("Popular Titles"),  0,                    Qt::CaseInsensitive);
   int pos_exact   = output.indexOf(QLatin1String("Exact Matches"),   qMax(pos_popular, 0), Qt::CaseInsensitive);
   int pos_partial = output.indexOf(QLatin1String("Partial Matches"), qMax(pos_exact, 0),   Qt::CaseInsensitive);
+  int pos_approx  = output.indexOf(QLatin1String("Approx Matches"),  qMax(pos_partial, 0), Qt::CaseInsensitive);
+
   int end_popular = pos_exact; // keep track of where to end
   if(end_popular == -1) {
-    end_popular = pos_partial == -1 ? output.length() : pos_partial;
+    end_popular = pos_partial == -1 ? (pos_approx == -1 ? output.length() : pos_approx) : pos_partial;
   }
   int end_exact = pos_partial; // keep track of where to end
   if(end_exact == -1) {
-    end_exact = output.length();
+    end_exact = pos_approx == -1 ? output.length() : pos_approx;
+  }
+  int end_partial = pos_approx; // keep track of where to end
+  if(end_partial == -1) {
+    end_partial = output.length();
   }
 
   // if found popular matches
@@ -304,7 +337,10 @@ void IMDBFetcher::parseMultipleTitleResults() {
     m_exactTitles = output.mid(pos_exact, end_exact-pos_exact);
   }
   if(pos_partial > -1) {
-    m_partialTitles = output.mid(pos_partial);
+    m_partialTitles = output.mid(pos_partial, end_partial-pos_partial);
+  }
+  if(pos_approx > -1) {
+    m_approxTitles = output.mid(pos_approx);
   }
 
   parseTitleBlock(m_popularTitles);
@@ -318,11 +354,16 @@ void IMDBFetcher::parseMultipleTitleResults() {
 
   if(m_matches.size() < m_limit) {
     parseTitleBlock(m_partialTitles);
-    m_currentTitleBlock = m_countOffset == 0 ? Unknown : Partial;
+    m_currentTitleBlock = m_countOffset == 0 ? Approx : Partial;
+  }
+
+  if(m_matches.size() < m_limit) {
+    parseTitleBlock(m_approxTitles);
+    m_currentTitleBlock = m_countOffset == 0 ? Unknown : Approx;
   }
 
   if(m_matches.size() == 0) {
-    myDebug() << "no matches found.";
+    myLog() << "no matches found.";
   }
 
   stop();
@@ -562,7 +603,7 @@ void IMDBFetcher::parseMultipleNameResults() {
       nameMap.insert(s, 1);
     }
     map.insert(s, u);
-    pos = s_anchorNameRx->indexIn(output, pos+s_anchorNameRx->cap(0).length());
+    pos = s_anchorNameRx->indexIn(output, pos+s_anchorNameRx->matchedLength());
   }
 
   if(map.count() == 0) {
@@ -634,11 +675,14 @@ Tellico::Data::EntryPtr IMDBFetcher::fetchEntryHook(uint uid_) {
     return entry;
   }
 
-  KUrl url = m_matches[uid_];
-  if(url.isEmpty()) {
-    myDebug() << "no url found";
+  if(!m_matches.contains(uid_)) {
+    myLog() << "no url found";
     return Data::EntryPtr();
   }
+  KUrl url = m_matches[uid_];
+  if(url.path().contains(QRegExp(QLatin1String("/tt\\d+/$"))))  {
+    url.setPath(url.path() + QLatin1String("combined"));
+  }
 
   KUrl origURL = m_url; // keep to switch back
   QString results;
@@ -668,7 +712,7 @@ Tellico::Data::EntryPtr IMDBFetcher::fetchEntryHook(uint uid_) {
 #endif
   }
   if(results.isEmpty()) {
-    myDebug() << "no text results";
+    myLog() << "no text results";
     m_url = origURL;
     return Data::EntryPtr();
   }
@@ -693,6 +737,7 @@ Tellico::Data::EntryPtr IMDBFetcher::parseEntry(const QString& str_) {
   doAlsoKnownAs(str_, entry);
   doPlot(str_, entry, m_url);
   doLists(str_, entry);
+  doStudio(str_, entry);
   doPerson(str_, entry, QLatin1String("Director"), QLatin1String("director"));
   doPerson(str_, entry, QLatin1String("Writer"), QLatin1String("writer"));
   doRating(str_, entry);
@@ -703,14 +748,19 @@ Tellico::Data::EntryPtr IMDBFetcher::parseEntry(const QString& str_) {
   }
 
   const QString imdb = QLatin1String("imdb");
-  if(!coll->hasField(imdb) && allOptionalFields().contains(imdb)) {
+  if(!coll->hasField(imdb) && optionalFields().contains(imdb)) {
     Data::FieldPtr field(new Data::Field(imdb, i18n("IMDb Link"), Data::Field::URL));
     field->setCategory(i18n("General"));
     coll->addField(field);
   }
   if(coll->hasField(imdb) && coll->fieldByName(imdb)->type() == Data::Field::URL) {
     m_url.setQuery(QString());
-    entry->setField(imdb, m_url.url());
+    // we want to strip the "/combined" fromt he url
+    QString url = m_url.url();
+    if(url.endsWith(QLatin1String("/combined"))) {
+      url = m_url.upUrl().url();
+    }
+    entry->setField(imdb, url);
   }
   return entry;
 }
@@ -758,13 +808,13 @@ void IMDBFetcher::doAspectRatio(const QString& str_, Tellico::Data::EntryPtr ent
 }
 
 void IMDBFetcher::doAlsoKnownAs(const QString& str_, Tellico::Data::EntryPtr entry_) {
-  if(!allOptionalFields().contains(QLatin1String("alttitle"))) {
+  if(!optionalFields().contains(QLatin1String("alttitle"))) {
     return;
   }
 
   // match until next b tag
 //  QRegExp akaRx(QLatin1String("also known as(.*)<b(?:\\s.*)?>"));
-  QRegExp akaRx(QLatin1String("also known as(.*)<(b[>\\s/]|div)"), Qt::CaseInsensitive);
+  QRegExp akaRx(QLatin1String("also known as(.*)<h5[>\\s/]"), Qt::CaseInsensitive);
   akaRx.setMinimal(true);
 
   if(akaRx.indexIn(str_) > -1 && !akaRx.cap(1).isEmpty()) {
@@ -786,13 +836,13 @@ void IMDBFetcher::doAlsoKnownAs(const QString& str_, Tellico::Data::EntryPtr ent
     for(QStringList::Iterator it = list.begin(); it != list.end(); ++it) {
       QString s = *it;
       // sometimes, the word "more" gets linked to the releaseinfo page, check that
-      if(s.indexOf(QLatin1String("releaseinfo")) > -1) {
+      if(s.contains(QLatin1String("releaseinfo"))) {
         continue;
       }
       s.remove(*s_tagRx);
       s.remove(brackRx);
       s = s.trimmed();
-      // the first value ends up being or starting with the colon after "Also know as"
+      // the first value ends up being or starting with the colon after "Also known as"
       // I'm too lazy to figure out a better regexp
       if(s.startsWith(QLatin1Char(':'))) {
         s = s.mid(1);
@@ -828,6 +878,8 @@ void IMDBFetcher::doPlot(const QString& str_, Tellico::Data::EntryPtr entry_, co
     if(plotRx.cap(0).endsWith(QLatin1String("(more)</")) || plotURLRx.indexIn(plotRx.cap(0)) > -1) {
       useUserSummary = true;
     }
+  } else {
+    useUserSummary = true;
   }
 
   if(useUserSummary) {
@@ -852,29 +904,56 @@ void IMDBFetcher::doPlot(const QString& str_, Tellico::Data::EntryPtr entry_, co
   }
 }
 
+void IMDBFetcher::doStudio(const QString& str_, Tellico::Data::EntryPtr entry_) {
+  // match until next opening tag
+  QRegExp productionRx(QLatin1String("Production Companies"), Qt::CaseInsensitive);
+  productionRx.setMinimal(true);
+  QRegExp blackcatRx(QLatin1String("blackcatheader"), Qt::CaseInsensitive);
+  blackcatRx.setMinimal(true);
+
+  const int pos1 = str_.indexOf(productionRx);
+  if(pos1 == -1) {
+    return;
+  }
+
+  int pos2 = str_.indexOf(blackcatRx, pos1);
+  if(pos2 == -1) {
+    pos2 = str_.length();
+  }
+
+  const QString text = str_.mid(pos1, pos2-pos1);
+  const QString company = QLatin1String("/company/");
+  QStringList studios;
+  for(int pos = s_anchorRx->indexIn(text); pos > -1; pos = s_anchorRx->indexIn(text, pos+s_anchorRx->matchedLength())) {
+    const QString cap1 = s_anchorRx->cap(1);
+    if(cap1.contains(company)) {
+      studios += s_anchorRx->cap(2).trimmed();
+    }
+  }
+
+  entry_->setField(QLatin1String("studio"), studios.join(FieldFormat::delimiterString()));
+}
+
 void IMDBFetcher::doPerson(const QString& str_, Tellico::Data::EntryPtr entry_,
                            const QString& imdbHeader_, const QString& fieldName_) {
   QRegExp br2Rx(QLatin1String("<br[\\s/]*>\\s*<br[\\s/]*>"), Qt::CaseInsensitive);
   br2Rx.setMinimal(true);
-  QRegExp divRx(QLatin1String("</div"), Qt::CaseInsensitive);
+  QRegExp divRx(QLatin1String("<div\\s[^>]*class\\s*=\\s*\"(?:info|txt-block)\"[^>]*>(.*)</div"), Qt::CaseInsensitive);
   divRx.setMinimal(true);
   QString name = QLatin1String("/name/");
 
   StringSet people;
-  for(int pos = str_.indexOf(imdbHeader_); pos > 0; pos = str_.indexOf(imdbHeader_, pos+1)) {
-    // loop until repeated <br> tags or </div> tag
-    const int endPos1 = br2Rx.indexIn(str_, pos);
-    const int endPos2 = divRx.indexIn(str_, pos);
-    const int endPos = endPos1 == -1 ? endPos2
-                                     : (endPos2 == -1 ? -1
-                                                      : qMin(endPos1, endPos2)
-                                       ); // ok to be -1
-    pos = s_anchorRx->indexIn(str_, pos+1);
-    while(pos > -1 && pos < endPos) {
-      if(s_anchorRx->cap(1).indexOf(name) > -1) {
-        people.add(s_anchorRx->cap(2).trimmed());
+  for(int pos = str_.indexOf(divRx); pos > -1; pos = str_.indexOf(divRx, pos+divRx.matchedLength())) {
+    const QString infoBlock = divRx.cap(1);
+    if(infoBlock.contains(imdbHeader_, Qt::CaseInsensitive)) {
+      int pos2 = s_anchorRx->indexIn(infoBlock);
+      while(pos2 > -1) {
+        if(s_anchorRx->cap(1).contains(name)) {
+          people.add(s_anchorRx->cap(2).trimmed());
+        }
+        pos2 = s_anchorRx->indexIn(infoBlock, pos2+s_anchorRx->matchedLength());
       }
-      pos = s_anchorRx->indexIn(str_, pos+1);
+      break;
     }
   }
   if(!people.isEmpty()) {
@@ -942,7 +1021,7 @@ void IMDBFetcher::doCast(const QString& str_, Tellico::Data::EntryPtr entry_, co
     }
   }
   if(pos == -1) { // no cast list found
-    myDebug() << "no cast list found";
+    myLog() << "no cast list found";
     return;
   }
 
@@ -955,11 +1034,11 @@ void IMDBFetcher::doCast(const QString& str_, Tellico::Data::EntryPtr entry_, co
   const int endPos = castText.indexOf(QLatin1String("</table"), pos, Qt::CaseInsensitive);
   pos = s_anchorRx->indexIn(castText, pos+1);
   while(pos > -1 && pos < endPos && cast.count() < m_numCast) {
-    if(s_anchorRx->cap(1).indexOf(name) > -1) {
+    if(s_anchorRx->cap(1).contains(name)) {
       // now search for <td> item with character name
       // there's a column with ellipses then the character
       const int pos2 = tdRx.indexIn(castText, pos);
-      if(pos2 > -1 && tdRx.indexIn(castText, pos2+1) > -1) {
+      if(pos2 > -1 && tdRx.indexIn(castText, pos2+tdRx.matchedLength()) > -1) {
         cast += s_anchorRx->cap(2).trimmed()
               + FieldFormat::columnDelimiterString()
               + tdRx.cap(1).simplified().remove(*s_tagRx);
@@ -976,7 +1055,7 @@ void IMDBFetcher::doCast(const QString& str_, Tellico::Data::EntryPtr entry_, co
 }
 
 void IMDBFetcher::doRating(const QString& str_, Tellico::Data::EntryPtr entry_) {
-  if(!allOptionalFields().contains(QLatin1String("imdb-rating"))) {
+  if(!optionalFields().contains(QLatin1String("imdb-rating"))) {
     return;
   }
 
@@ -1003,7 +1082,6 @@ void IMDBFetcher::doRating(const QString& str_, Tellico::Data::EntryPtr entry_)
 }
 
 void IMDBFetcher::doCover(const QString& str_, Tellico::Data::EntryPtr entry_, const KUrl& baseURL_) {
-  // cover is the img with the "cover" alt text
   QRegExp imgRx(QLatin1String("<img\\s+[^>]*src\\s*=\\s*\"([^\"]*)\"[^>]*>"), Qt::CaseInsensitive);
   imgRx.setMinimal(true);
 
@@ -1014,81 +1092,117 @@ void IMDBFetcher::doCover(const QString& str_, Tellico::Data::EntryPtr entry_, c
 
   int pos = posterRx.indexIn(str_);
   while(pos > -1) {
-    if(imgRx.indexIn(posterRx.cap(1)) > -1) {
+    if(posterRx.cap(1).contains(imgRx)) {
       KUrl u(baseURL_, imgRx.cap(1));
       QString id = ImageFactory::addImage(u, true);
       if(!id.isEmpty()) {
         entry_->setField(cover, id);
+        return;
       }
-      return;
     }
-    pos = posterRx.indexIn(str_, pos+1);
+    pos = posterRx.indexIn(str_, pos+posterRx.matchedLength());
   }
 
   // didn't find the cover, IMDb also used to put "cover" inside the url
+  // cover is the img with the "cover" alt text
+
   pos = imgRx.indexIn(str_);
   while(pos > -1) {
-    if(imgRx.cap(0).indexOf(cover, 0, Qt::CaseInsensitive) > -1) {
+    const QString url = imgRx.cap(0).toLower();
+    if(url.contains(cover)) {
       KUrl u(baseURL_, imgRx.cap(1));
       QString id = ImageFactory::addImage(u, true);
       if(!id.isEmpty()) {
         entry_->setField(cover, id);
+        return;
       }
-      return;
     }
-    pos = imgRx.indexIn(str_, pos+1);
+    pos = imgRx.indexIn(str_, pos+imgRx.matchedLength());
+  }
+  
+  // also check for <link rel='image_src'
+  QRegExp linkRx(QLatin1String("<link (.*)>"), Qt::CaseInsensitive);
+  linkRx.setMinimal(true);
+
+  const QString src = QLatin1String("image_src");
+
+  pos = linkRx.indexIn(str_);
+  while(pos > -1) {
+    const QString tag = linkRx.cap(1);
+    if(tag.contains(src, Qt::CaseInsensitive)) {
+      QRegExp hrefRx(QLatin1String("href=['\"](.*)['\"]"), Qt::CaseInsensitive);
+      hrefRx.setMinimal(true);
+      if(hrefRx.indexIn(tag) > -1) {
+        KUrl u(baseURL_, hrefRx.cap(1));
+        QString id = ImageFactory::addImage(u, true);
+        if(!id.isEmpty()) {
+          entry_->setField(cover, id);
+          return;
+        }
+      }
+    }
+    pos = linkRx.indexIn(str_, pos+linkRx.matchedLength());
   }
 }
 
-// end up reparsing whole string, but it's not really that slow
 // look at every anchor tag in the string
 void IMDBFetcher::doLists(const QString& str_, Tellico::Data::EntryPtr entry_) {
   const QString genre = QLatin1String("/Genres/");
-  const QString country = QLatin1String("/Countries/");
-  const QString lang = QLatin1String("/Languages/");
-  const QString colorInfo = QLatin1String("color-info");
+  const QString genre2 = QLatin1String("/genre/");
+  const QString country = QLatin1String("/country/");
+  const QString lang = QLatin1String("/language/");
+  const QString colorInfo = QLatin1String("colors=");
   const QString cert = QLatin1String("certificates=");
-  const QString soundMix = QLatin1String("sound-mix=");
+  const QString soundMix = QLatin1String("sound_mixes=");
   const QString year = QLatin1String("/Years/");
-  const QString company = QLatin1String("/company/");
 
-  // IIMdb also has links with the word "sections" in them, remove that
+  // if we reach faqs or user comments, we can stop
+  const QString faqs = QLatin1String("/faq");
+  const QString users = QLatin1String("/user/");
+  // IMdb also has links with the word "sections" in them, remove that
   // for genres and nationalities
 
-  QStringList genres, countries, langs, certs, tracks, studios;
-  for(int pos = s_anchorRx->indexIn(str_); pos > -1; pos = s_anchorRx->indexIn(str_, pos+1)) {
+  int startPos = str_.indexOf(QLatin1String("<div id=\"pagecontent\">"));
+  if(startPos == -1) {
+    startPos = 0;
+  }
+
+  QStringList genres, countries, langs, certs, tracks;
+  for(int pos = s_anchorRx->indexIn(str_, startPos); pos > -1; pos = s_anchorRx->indexIn(str_, pos+s_anchorRx->matchedLength())) {
     const QString cap1 = s_anchorRx->cap(1);
-    if(cap1.indexOf(genre) > -1) {
-      if(s_anchorRx->cap(2).indexOf(QLatin1String(" section"), 0, Qt::CaseInsensitive) == -1) {
+    if(cap1.contains(genre) || cap1.contains(genre2)) {
+      if(!s_anchorRx->cap(2).contains(QLatin1String(" section"), Qt::CaseInsensitive)) {
         genres += s_anchorRx->cap(2).trimmed();
       }
-    } else if(cap1.indexOf(country) > -1) {
-      if(s_anchorRx->cap(2).indexOf(QLatin1String(" section"), 0, Qt::CaseInsensitive) == -1) {
+    } else if(cap1.contains(country)) {
+      if(!s_anchorRx->cap(2).contains(QLatin1String(" section"), Qt::CaseInsensitive)) {
         countries += s_anchorRx->cap(2).trimmed();
       }
-    } else if(cap1.indexOf(lang) > -1) {
+    } else if(cap1.contains(lang)) {
       langs += s_anchorRx->cap(2).trimmed();
-    } else if(cap1.indexOf(colorInfo) > -1) {
+    } else if(cap1.contains(colorInfo)) {
       // change "black and white" to "black & white"
       entry_->setField(QLatin1String("color"),
                        s_anchorRx->cap(2).replace(QLatin1String("and"), QLatin1String("&")).trimmed());
-    } else if(cap1.indexOf(cert) > -1) {
+    } else if(cap1.contains(cert)) {
       certs += s_anchorRx->cap(2).trimmed();
-    } else if(cap1.indexOf(soundMix) > -1) {
+    } else if(cap1.contains(soundMix)) {
       tracks += s_anchorRx->cap(2).trimmed();
-    } else if(cap1.indexOf(company) > -1) {
-      studios += s_anchorRx->cap(2).trimmed();
       // if year field wasn't set before, do it now
-    } else if(entry_->field(QLatin1String("year")).isEmpty() && cap1.indexOf(year) > -1) {
+    } else if(entry_->field(QLatin1String("year")).isEmpty() && cap1.contains(year)) {
       entry_->setField(QLatin1String("year"), s_anchorRx->cap(2).trimmed());
+    } else if((cap1.contains(faqs) || cap1.contains(users)) && !genres.isEmpty()) {
+      break;
     }
   }
 
+  // since we have multiple genre search strings
+  genres.removeDuplicates();
+
   entry_->setField(QLatin1String("genre"), genres.join(FieldFormat::delimiterString()));
   entry_->setField(QLatin1String("nationality"), countries.join(FieldFormat::delimiterString()));
   entry_->setField(QLatin1String("language"), langs.join(FieldFormat::delimiterString()));
   entry_->setField(QLatin1String("audio-track"), tracks.join(FieldFormat::delimiterString()));
-  entry_->setField(QLatin1String("studio"), studios.join(FieldFormat::delimiterString()));
   if(!certs.isEmpty()) {
     // first try to set default certification
     const QStringList& certsAllowed = entry_->collection()->fieldByName(QLatin1String("certification"))->allowed();
@@ -1099,7 +1213,7 @@ void IMDBFetcher::doLists(const QString& str_, Tellico::Data::EntryPtr entry_) {
         lcert = QLatin1Char('U');
       }
       lcert += QLatin1String(" (") + country + QLatin1Char(')');
-      if(certsAllowed.indexOf(cert) > -1) {
+      if(certsAllowed.contains(cert)) {
         entry_->setField(QLatin1String("certification"), lcert);
         break;
       }
@@ -1107,7 +1221,7 @@ void IMDBFetcher::doLists(const QString& str_, Tellico::Data::EntryPtr entry_) {
 
     // now add new field for all certifications
     const QString allc = QLatin1String("allcertification");
-    if(allOptionalFields().contains(allc)) {
+    if(optionalFields().contains(allc)) {
       Data::FieldPtr f = entry_->collection()->fieldByName(allc);
       if(!f) {
         f = new Data::Field(allc, i18n("Certifications"), Data::Field::Table);
@@ -1124,28 +1238,11 @@ Tellico::Fetch::FetchRequest IMDBFetcher::updateRequest(Data::EntryPtr entry_) {
   KUrl link = entry_->field(QLatin1String("imdb"));
 
   if(!link.isEmpty() && link.isValid()) {
-    myWarning() << "IMDb link searching not implemented";
-    return FetchRequest(Title, t);
-
-    // TODO: fix this
-    // check if we want a different host
     if(link.host() != m_host) {
 //      myLog() << "switching hosts to " << m_host;
       link.setHost(m_host);
     }
-//    request().key = Fetch::Title;
-//    request().value = t;
-    m_started = true;
-    m_text.clear();
-    m_matches.clear();
-    m_url = link;
-    m_redirected = true; // m_redirected is used as a flag later to tell if we get a single result
-    m_job = KIO::storedGet(m_url, KIO::NoReload, KIO::HideProgressInfo);
-    m_job->ui()->setWindow(GUI::Proxy::widget());
-    connect(m_job, SIGNAL(result(KJob*)),
-            SLOT(slotComplete(KJob*)));
-    connect(m_job, SIGNAL(redirection(KIO::Job*, const KUrl&)),
-            SLOT(slotRedirection(KIO::Job*, const KUrl&)));
+    return FetchRequest(Fetch::Raw, link.url());
   }
 
   // optimistically try searching for title and rely on Collection::sameEntry() to figure things out
@@ -1162,12 +1259,13 @@ QString IMDBFetcher::defaultName() {
 QString IMDBFetcher::defaultIcon() {
   return favIcon("http://imdb.com");
 }
+
 //static
 Tellico::StringHash IMDBFetcher::allOptionalFields() {
   StringHash hash;
-  hash[QLatin1String("imdb")]             = i18n("IMDb Link");
-  hash[QLatin1String("imdb-rating")]      = i18n("IMDb Rating");
-  hash[QLatin1String("alttitle")]         = i18n("Alternative Titles");
+  hash[QLatin1String("imdb")]            = i18n("IMDb Link");
+  hash[QLatin1String("imdb-rating")]     = i18n("IMDb Rating");
+  hash[QLatin1String("alttitle")]        = i18n("Alternative Titles");
   hash[QLatin1String("allcertification")] = i18n("Certifications");
   return hash;
 }
