@@ -10,7 +10,7 @@
  *   the License or (at your option) version 3 or any later version        *
  *   accepted by the membership of KDE e.V. (or its successor approved     *
  *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
+ *   defined in Section 14 of version 3 of the license.                     *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
@@ -50,6 +50,7 @@
 #include "translators/bibtexhandler.h" // needed for bibtex options
 #include "fetchdialog.h"
 #include "reportdialog.h"
+#include "bibtexkeydialog.h"
 #include "tellico_strings.h"
 #include "filterview.h"
 #include "loanview.h"
@@ -63,7 +64,7 @@
 #include "gui/lineedit.h"
 #include "gui/statusbar.h"
 #include "gui/cursorsaver.h"
-#include "gui/guiproxy.cpp"
+#include "gui/guiproxy.h"
 #include "tellico_debug.h"
 
 #include <kapplication.h>
@@ -140,12 +141,14 @@ MainWindow::MainWindow(QWidget* parent_/*=0*/) : KXmlGuiWindow(parent_),
     m_filterDlg(0),
     m_collFieldsDlg(0),
     m_stringMacroDlg(0),
+    m_bibtexKeyDlg(0),
     m_fetchDlg(0),
     m_reportDlg(0),
     m_queuedFilters(0),
     m_initialized(false),
     m_newDocument(true),
-    m_dontQueueFilter(false) {
+    m_dontQueueFilter(false),
+    m_savingImageLocationChange(false) {
 
   Controller::init(this); // the only time this is ever called!
   // has to be after controller init
@@ -192,6 +195,7 @@ MainWindow::~MainWindow() {
 }
 
 void MainWindow::slotInit() {
+  MARK;
   if(m_editDialog) {
     return;
   }
@@ -274,7 +278,7 @@ void MainWindow::initActions() {
   COLL_ACTION(BoardGame, "new_boardgame_collection", i18n("New Boa&rd Game Collection"),
               i18n("Create a new board game collection"), "boardgame");
 
-  COLL_ACTION(File, "BoardGame", i18n("New &File Catalog"),
+  COLL_ACTION(File, "new_file_catalog", i18n("New &File Catalog"),
               i18n("Create a new file catalog"), "file");
 
   action = actionCollection()->addAction(QLatin1String("new_custom_collection"), collectionMapper, SLOT(map()));
@@ -323,7 +327,7 @@ void MainWindow::initActions() {
   importMapper->setMapping(action, TYPE);
 
   IMPORT_ACTION(Import::TellicoXML, "file_import_tellico", i18n("Import Tellico Data..."),
-                i18n("Import another Tellico data file"), KIcon(QLatin1String("tellico")));
+                i18n("Import another Tellico data file"), BarIcon(QLatin1String("tellico")));
 
   IMPORT_ACTION(Import::CSV, "file_import_csv", i18n("Import CSV Data..."),
                 i18n("Import a CSV file"), mimeIcon("text/csv", "text/x-csv"));
@@ -332,13 +336,13 @@ void MainWindow::initActions() {
                 i18n("Import a MODS data file"), mimeIcon("text/xml"));
 
   IMPORT_ACTION(Import::Alexandria, "file_import_alexandria", i18n("Import Alexandria Data..."),
-                i18n("Import data from the Alexandria book collection manager"), KIcon(QLatin1String("alexandria")));
+                i18n("Import data from the Alexandria book collection manager"), BarIcon(QLatin1String("alexandria")));
 
   IMPORT_ACTION(Import::Delicious, "file_import_delicious", i18n("Import Delicious Library Data..."),
-                i18n("Import data from Delicious Library"), mimeIcon("text/xml"));
+                i18n("Import data from Delicious Library"), BarIcon(QLatin1String("deliciouslibrary")));
 
   IMPORT_ACTION(Import::Referencer, "file_import_referencer", i18n("Import Referencer Data..."),
-                i18n("Import data from Referencer"), KIcon(QLatin1String("referencer")));
+                i18n("Import data from Referencer"), BarIcon(QLatin1String("referencer")));
 
   IMPORT_ACTION(Import::Bibtex, "file_import_bibtex", i18n("Import Bibtex Data..."),
                 i18n("Import a bibtex bibliography file"), mimeIcon("text/x-bibtex"));
@@ -347,13 +351,13 @@ void MainWindow::initActions() {
                 i18n("Import a Bibtexml bibliography file"), mimeIcon("text/xml"));
 
   IMPORT_ACTION(Import::RIS, "file_import_ris", i18n("Import RIS Data..."),
-                i18n("Import an RIS reference file"), mimeIcon("application/x-research-info-systems"));
+                i18n("Import an RIS reference file"), BarIcon(QLatin1String("cite")));
 
   IMPORT_ACTION(Import::PDF, "file_import_pdf", i18n("Import PDF File..."),
                 i18n("Import a PDF file"), mimeIcon("application/pdf"));
 
   IMPORT_ACTION(Import::AudioFile, "file_import_audiofile", i18n("Import Audio File Metadata..."),
-                i18n("Import meta-data from audio files"), mimeIcon("audio/mp3", "audioaudio/x-mp3"));
+                i18n("Import meta-data from audio files"), mimeIcon("audio/mp3", "audio/x-mp3"));
 #ifndef HAVE_TAGLIB
   action->setEnabled(false);
 #endif
@@ -365,13 +369,13 @@ void MainWindow::initActions() {
 #endif
 
   IMPORT_ACTION(Import::GCstar, "file_import_gcstar", i18n("Import GCstar Data..."),
-                i18n("Import a GCstar data file"), KIcon(QLatin1String("gcstar")));
+                i18n("Import a GCstar data file"), BarIcon(QLatin1String("gcstar")));
 
   IMPORT_ACTION(Import::Griffith, "file_import_griffith", i18n("Import Griffith Data..."),
-                i18n("Import a Griffith database"), KIcon(QLatin1String("griffith")));
+                i18n("Import a Griffith database"), BarIcon(QLatin1String("griffith")));
 
   IMPORT_ACTION(Import::AMC, "file_import_amc", i18n("Import Ant Movie Catalog Data..."),
-                i18n("Import an Ant Movie Catalog data file"), mimeIcon("application/x-crossover-amc"));
+                i18n("Import an Ant Movie Catalog data file"), BarIcon(QLatin1String("amc")));
 
   IMPORT_ACTION(Import::FileListing, "file_import_filelisting", i18n("Import File Listing..."),
                 i18n("Import information about files in a folder"), mimeIcon("inode/directory"));
@@ -402,10 +406,10 @@ void MainWindow::initActions() {
   exportMapper->setMapping(action, TYPE);
 
   EXPORT_ACTION(Export::TellicoXML, "file_export_xml", i18n("Export to XML..."),
-                i18n("Export to a Tellico XML file"), KIcon(QLatin1String("tellico")));
+                i18n("Export to a Tellico XML file"), BarIcon(QLatin1String("tellico")));
 
   EXPORT_ACTION(Export::TellicoZip, "file_export_zip", i18n("Export to Zip..."),
-                i18n("Export to a Tellico Zip file"), KIcon(QLatin1String("tellico")));
+                i18n("Export to a Tellico Zip file"), BarIcon(QLatin1String("tellico")));
 
   EXPORT_ACTION(Export::HTML, "file_export_html", i18n("Export to HTML..."),
                 i18n("Export to an HTML file"), mimeIcon("text/html"));
@@ -414,10 +418,10 @@ void MainWindow::initActions() {
                 i18n("Export to a comma-separated values file"), mimeIcon("text/csv", "text/x-csv"));
 
   EXPORT_ACTION(Export::PilotDB, "file_export_pilotdb", i18n("Export to PilotDB..."),
-                i18n("Export to a PilotDB database"), mimeIcon("application/vnd.palm"));
+                i18n("Export to a PilotDB database"), BarIcon(QLatin1String("palm")));
 
   EXPORT_ACTION(Export::Alexandria, "file_export_alexandria", i18n("Export to Alexandria..."),
-                i18n("Export to an Alexandria library"), KIcon(QLatin1String("alexandria")));
+                i18n("Export to an Alexandria library"), BarIcon(QLatin1String("alexandria")));
 
   EXPORT_ACTION(Export::Bibtex, "file_export_bibtex", i18n("Export to Bibtex..."),
                 i18n("Export to a bibtex file"), mimeIcon("text/x-bibtex"));
@@ -429,7 +433,7 @@ void MainWindow::initActions() {
                 i18n("Export to an ONIX file"), mimeIcon("text/xml"));
 
   EXPORT_ACTION(Export::GCstar, "file_export_gcstar", i18n("Export to GCstar..."),
-                i18n("Export to a GCstar data file"), KIcon(QLatin1String("gcstar")));
+                i18n("Export to a GCstar data file"), BarIcon(QLatin1String("gcstar")));
 
   EXPORT_ACTION(Export::XSLT, "file_export_xslt", i18n("Export XSL Transform..."),
                 i18n("Export using an XSL Transform"), mimeIcon("application/xslt+xml", "text/x-xslt"));
@@ -508,12 +512,6 @@ void MainWindow::initActions() {
   m_mergeEntry->setToolTip(i18n("Merge the selected entries"));
   m_mergeEntry->setEnabled(false); // gets enabled when more than 1 entry is selected
 
-  action = actionCollection()->addAction(QLatin1String("coll_reports"), this, SLOT(slotShowReportDialog()));
-  action->setText(i18n("&Generate Reports..."));
-  action->setIconText(i18n("Reports"));
-  action->setIcon(KIcon(QLatin1String("text-rdf")));
-  action->setToolTip(i18n("Generate collection reports"));
-
   m_checkOutEntry = actionCollection()->addAction(QLatin1String("coll_checkout"), Controller::self(), SLOT(slotCheckOut()));
   m_checkOutEntry->setText(i18n("Check-&out..."));
   m_checkOutEntry->setIcon(KIcon(QLatin1String("arrow-up-double")));
@@ -537,6 +535,12 @@ void MainWindow::initActions() {
   action->setShortcut(Qt::CTRL + Qt::Key_U);
   action->setToolTip(i18n("Modify the collection fields"));
 
+  action = actionCollection()->addAction(QLatin1String("coll_reports"), this, SLOT(slotShowReportDialog()));
+  action->setText(i18n("&Generate Reports..."));
+  action->setIconText(i18n("Reports"));
+  action->setIcon(KIcon(QLatin1String("text-rdf")));
+  action->setToolTip(i18n("Generate collection reports"));
+
   action = actionCollection()->addAction(QLatin1String("coll_convert_bibliography"), this, SLOT(slotConvertToBibliography()));
   action->setText(i18n("Convert to &Bibliography"));
   action->setIcon(KIcon(QLatin1String("bibtex")));
@@ -547,6 +551,11 @@ void MainWindow::initActions() {
   action->setIcon(KIcon(QLatin1String("fileview-text")));
   action->setToolTip(i18n("Edit the bibtex string macros"));
 
+  action = actionCollection()->addAction(QLatin1String("coll_key_manager"), this, SLOT(slotShowBibtexKeyDialog()));
+  action->setText(i18n("Check for Duplicate Keys..."));
+  action->setIcon(KIcon(QLatin1String("text/x-bibtex")));
+  action->setToolTip(i18n("Check for duplicate citation keys"));
+
   QSignalMapper* citeMapper = new QSignalMapper(this);
   connect(citeMapper, SIGNAL(mapped(int)),
           this, SLOT(slotCiteEntry(int)));
@@ -689,6 +698,7 @@ void MainWindow::initView() {
 
   m_viewTabs = new KTabWidget(m_split);
   m_viewTabs->setTabBarHidden(true);
+  m_viewTabs->setDocumentMode(true);
   m_groupView = new GroupView(m_viewTabs);
   Controller::self()->addObserver(m_groupView);
   m_viewTabs->addTab(m_groupView, KIcon(QLatin1String("folder")), i18n("Groups"));
@@ -719,7 +729,7 @@ void MainWindow::initConnections() {
 
   // let the group view call filters, too
   connect(m_groupView, SIGNAL(signalUpdateFilter(Tellico::FilterPtr)),
-          Controller::self(), SLOT(slotUpdateFilter(Tellico::FilterPtr)));
+          this, SLOT(slotUpdateFilter(Tellico::FilterPtr)));
 }
 
 void MainWindow::initFileOpen(bool nofile_) {
@@ -1089,6 +1099,7 @@ void MainWindow::openFile(const QString& file_) {
 }
 
 bool MainWindow::openURL(const KUrl& url_) {
+  MARK;
   // try to open document
   GUI::CursorSaver cs(Qt::WaitCursor);
 
@@ -1295,15 +1306,15 @@ void MainWindow::slotFileQuit() {
 }
 
 void MainWindow::slotEditCut() {
-  activateEditSlot(SLOT(cut()));
+  activateEditSlot("cut()");
 }
 
 void MainWindow::slotEditCopy() {
-  activateEditSlot(SLOT(copy()));
+  activateEditSlot("copy()");
 }
 
 void MainWindow::slotEditPaste() {
-  activateEditSlot(SLOT(paste()));
+  activateEditSlot("paste()");
 }
 
 void MainWindow::activateEditSlot(const char* slot_) {
@@ -1317,11 +1328,10 @@ void MainWindow::activateEditSlot(const char* slot_) {
 
   if(w && w->isVisible()) {
     const QMetaObject* meta = w->metaObject();
-
-    int idx = meta->indexOfSlot(slot_);
+    const int idx = meta->indexOfSlot(slot_);
     if(idx > -1) {
       myDebug() << "MainWindow invoking" << meta->method(idx).signature();
-      QMetaObject::invokeMethod(w, slot_);
+      meta->method(idx).invoke(w, Qt::DirectConnection);
     }
   }
 }
@@ -1535,7 +1545,6 @@ void MainWindow::slotUpdateCollectionToolBar(Tellico::Data::CollPtr coll_) {
 }
 
 void MainWindow::slotChangeGrouping() {
-//  DEBUG_LINE;
   QString title = m_entryGrouping->currentText();
 
   QString groupName = Kernel::self()->fieldNameByTitle(title);
@@ -1551,7 +1560,6 @@ void MainWindow::slotChangeGrouping() {
 }
 
 void MainWindow::slotShowReportDialog() {
-//  DEBUG_LINE;
   if(!m_reportDlg) {
     m_reportDlg = new ReportDialog(this);
     connect(m_reportDlg, SIGNAL(finished()),
@@ -1599,9 +1607,7 @@ void MainWindow::slotShowFilterDialog() {
     connect(m_filterDlg, SIGNAL(signalCollectionModified()),
             Data::Document::self(), SLOT(slotSetModified()));
     connect(m_filterDlg, SIGNAL(signalUpdateFilter(Tellico::FilterPtr)),
-            this, SLOT(slotClearFilterNow()));
-    connect(m_filterDlg, SIGNAL(signalUpdateFilter(Tellico::FilterPtr)),
-            Controller::self(), SLOT(slotUpdateFilter(Tellico::FilterPtr)));
+            this, SLOT(slotUpdateFilter(Tellico::FilterPtr)));
     connect(m_filterDlg, SIGNAL(finished()),
             SLOT(slotHideFilterDialog()));
   } else {
@@ -1621,7 +1627,7 @@ void MainWindow::slotHideFilterDialog() {
 }
 
 void MainWindow::slotQueueFilter() {
-  if (m_dontQueueFilter) {
+  if(m_dontQueueFilter) {
     return;
   }
   m_queuedFilters++;
@@ -1637,11 +1643,11 @@ void MainWindow::slotUpdateFilter() {
   setFilter(m_quickFilter->text());
 }
 
-void MainWindow::slotClearFilterNow() {
+void MainWindow::slotUpdateFilter(FilterPtr filter_) {
   // Can't just block signals because clear button won't show then
   m_dontQueueFilter = true;
   m_quickFilter->setText(QLatin1String(" ")); // To be able to clear custom filter
-  setFilter(QString());
+  Controller::self()->slotUpdateFilter(filter_);
   m_dontQueueFilter = false;
 }
 
@@ -1821,6 +1827,29 @@ void MainWindow::slotStringMacroDialogOk() {
   }
 }
 
+void MainWindow::slotShowBibtexKeyDialog() {
+  if(Data::Document::self()->collection()->type() != Data::Collection::Bibtex) {
+    return;
+  }
+
+  if(!m_bibtexKeyDlg) {
+    m_bibtexKeyDlg = new BibtexKeyDialog(Data::Document::self()->collection(), this);
+    connect(m_bibtexKeyDlg, SIGNAL(finished()), SLOT(slotHideBibtexKeyDialog()));
+    connect(m_bibtexKeyDlg, SIGNAL(signalUpdateFilter(Tellico::FilterPtr)),
+            this, SLOT(slotUpdateFilter(Tellico::FilterPtr)));
+  } else {
+    KWindowSystem::activateWindow(m_bibtexKeyDlg->winId());
+  }
+  m_bibtexKeyDlg->show();
+}
+
+void MainWindow::slotHideBibtexKeyDialog() {
+  if(m_bibtexKeyDlg) {
+    m_bibtexKeyDlg->delayedDestruct();
+    m_bibtexKeyDlg = 0;
+  }
+}
+
 void MainWindow::slotNewEntry() {
   m_toggleEntryEditor->setChecked(true);
   slotToggleEntryEditor();
@@ -1971,6 +2000,8 @@ void MainWindow::addFilterView() {
   m_viewTabs->insertTab(1, m_filterView, KIcon(QLatin1String("view-filter")), i18n("Filters"));
   m_filterView->setWhatsThis(i18n("<qt>The <i>Filter View</i> shows the entries which meet certain "
                                   "filter rules.</qt>"));
+  connect(m_filterView, SIGNAL(signalUpdateFilter(Tellico::FilterPtr)),
+          this, SLOT(slotUpdateFilter(Tellico::FilterPtr)));
 
   // sort by count if column = 1
   int sortRole = Config::filterViewSortColumn() == 0 ? static_cast<int>(Qt::DisplayRole) : static_cast<int>(RowCountRole);
@@ -2052,12 +2083,17 @@ void MainWindow::slotRenameCollection() {
 }
 
 void MainWindow::slotImageLocationChanged() {
+  if(m_savingImageLocationChange) {
+    return;
+  }
+  m_savingImageLocationChange = true;
   Data::Document::self()->slotSetModified();
   KMessageBox::information(this, QLatin1String("<qt>") +
                                  i18n("Some images are not saved in the configured location. The current file "
                                       "must be saved and the images will be transferred to the new location.") +
                                  QLatin1String("</qt>"));
   fileSave();
+  m_savingImageLocationChange = false;
 }
 
 void MainWindow::updateCollectionActions() {
@@ -2066,20 +2102,10 @@ void MainWindow::updateCollectionActions() {
   }
 
   stateChanged(QLatin1String("collection_reset"));
+
   Data::Collection::Type type = Data::Document::self()->collection()->type();
-  switch(type) {
-    case Data::Collection::Book:
-      stateChanged(QLatin1String("is_book"));
-      break;
-    case Data::Collection::Bibtex:
-      stateChanged(QLatin1String("is_bibliography"));
-      break;
-    case Data::Collection::Video:
-      stateChanged(QLatin1String("is_video"));
-      break;
-    default:
-      break;
-  }
+  stateChanged(QLatin1String("is_") + CollectionFactory::typeName(type));
+
   Controller::self()->updateActions();
   // special case when there are no available data sources
   if(m_fetchActions.isEmpty() && m_updateAll) {
