@@ -80,7 +80,7 @@ Tellico::Data::CollPtr CSVImporter::collection() {
   }
 
   if(!m_coll) {
-    m_coll = CollectionFactory::collection(m_comboColl->currentType(), true);
+    createCollection();
   }
 
   const QStringList existingNames = m_coll->fieldNames();
@@ -89,17 +89,7 @@ Tellico::Data::CollPtr CSVImporter::collection() {
   QStringList names;
   for(int col = 0; col < m_table->columnCount(); ++col) {
     QString t = m_table->horizontalHeaderItem(col)->text();
-    if(m_existingCollection && m_existingCollection->fieldByTitle(t)) {
-      // the collection might have the right field, but a different title, say for translations
-      Data::FieldPtr f = m_existingCollection->fieldByTitle(t);
-      if(m_coll->hasField(f->name())) {
-        // might have different values settings
-        m_coll->removeField(f->name(), true /* force */);
-      }
-      m_coll->addField(Data::FieldPtr(new Data::Field(*f)));
-      cols << col;
-      names << f->name();
-    } else if(m_coll->fieldByTitle(t)) {
+    if(m_coll->fieldByTitle(t)) {
       cols << col;
       names << m_coll->fieldNameByTitle(t);
     }
@@ -121,14 +111,26 @@ Tellico::Data::CollPtr CSVImporter::collection() {
   const uint stepSize = qMax(s_stepSize, numChars/100);
   const bool showProgress = options() & ImportProgress;
 
+  // do we need to replace column or row delimiters
+  const bool replaceColDelimiter = (!m_colDelimiter.isEmpty() && m_colDelimiter != FieldFormat::columnDelimiterString());
+  const bool replaceRowDelimiter = (!m_rowDelimiter.isEmpty() && m_rowDelimiter != FieldFormat::rowDelimiterString());
+
   uint j = 0;
   while(!m_cancelled && m_parser->hasNext()) {
     bool empty = true;
     Data::EntryPtr entry(new Data::Entry(m_coll));
     QStringList values = m_parser->nextTokens();
     for(int i = 0; i < names.size(); ++i) {
-//      QString value = values[cols[i]].simplified();
+      if(cols[i] >= values.size()) {
+        break;
+      }
       QString value = values[cols[i]].trimmed();
+      if(replaceColDelimiter) {
+        value.replace(m_colDelimiter, FieldFormat::columnDelimiterString());
+      }
+      if(replaceRowDelimiter) {
+        value.replace(m_rowDelimiter, FieldFormat::rowDelimiterString());
+      }
       bool success = entry->setField(names[i], value);
       // we might need to add a new allowed value
       // assume that if the user is importing the value, it should be allowed
@@ -159,6 +161,8 @@ Tellico::Data::CollPtr CSVImporter::collection() {
   {
     KConfigGroup config(KGlobal::config(), QLatin1String("ImportOptions - CSV"));
     config.writeEntry("Delimiter", m_delimiter);
+    config.writeEntry("ColumnDelimiter", m_colDelimiter);
+    config.writeEntry("RowDelimiter", m_rowDelimiter);
     config.writeEntry("First Row Titles", m_firstRowHeader);
   }
 
@@ -198,7 +202,7 @@ QWidget* CSVImporter::widget(QWidget* parent_) {
 
   lab = new QLabel(i18n("Delimiter:"), groupBox);
   lab->setWhatsThis(i18n("In addition to a comma, other characters may be used as "
-                                      "a delimiter, separating each value in the file."));
+                         "a delimiter, separating each value in the file."));
   delimiterLayout->addWidget(lab);
 
   m_radioComma = new QRadioButton(groupBox);
@@ -241,6 +245,33 @@ QWidget* CSVImporter::widget(QWidget* parent_) {
   buttonGroup->addButton(m_radioOther);
   connect(buttonGroup, SIGNAL(buttonClicked(int)), SLOT(slotDelimiter()));
 
+  QHBoxLayout* delimiterLayout2 = new QHBoxLayout();
+  vlay->addLayout(delimiterLayout2);
+
+  QString w = i18n("The column delimiter separates values in each column of a <i>Table</i> field.");
+  lab = new QLabel(i18n("Table column delimiter:"), groupBox);
+  lab->setWhatsThis(w);
+  delimiterLayout2->addWidget(lab);
+  m_editColDelimiter = new KLineEdit(groupBox);
+  m_editColDelimiter->setWhatsThis(w);
+  m_editColDelimiter->setFixedWidth(m_widget->fontMetrics().width(QLatin1Char('X')) * 4);
+  m_editColDelimiter->setMaxLength(1);
+  delimiterLayout2->addWidget(m_editColDelimiter);
+  connect(m_editColDelimiter, SIGNAL(textChanged(const QString&)), SLOT(slotDelimiter()));
+
+  w = i18n("The row delimiter separates values in each row of a <i>Table</i> field.");
+  lab = new QLabel(i18n("Table row delimiter:"), groupBox);
+  lab->setWhatsThis(w);
+  delimiterLayout2->addWidget(lab);
+  m_editRowDelimiter = new KLineEdit(groupBox);
+  m_editRowDelimiter->setWhatsThis(w);
+  m_editRowDelimiter->setFixedWidth(m_widget->fontMetrics().width(QLatin1Char('X')) * 4);
+  m_editRowDelimiter->setMaxLength(1);
+  delimiterLayout2->addWidget(m_editRowDelimiter);
+  connect(m_editRowDelimiter, SIGNAL(textChanged(const QString&)), SLOT(slotDelimiter()));
+
+  delimiterLayout2->addStretch(10);
+
   m_table = new QTableWidget(5, 0, groupBox);
   vlay->addWidget(m_table);
   m_table->setSelectionMode(QAbstractItemView::SingleSelection);
@@ -293,12 +324,13 @@ QWidget* CSVImporter::widget(QWidget* parent_) {
 
   KConfigGroup config(KGlobal::config(), QLatin1String("ImportOptions - CSV"));
   m_delimiter = config.readEntry("Delimiter", m_delimiter);
+  m_colDelimiter = config.readEntry("ColumnDelimiter", m_colDelimiter);
+  m_rowDelimiter = config.readEntry("RowDelimiter", m_rowDelimiter);
   m_firstRowHeader = config.readEntry("First Row Titles", m_firstRowHeader);
 
   m_checkFirstRowHeader->setChecked(m_firstRowHeader);
   if(m_delimiter == QLatin1String(",")) {
     m_radioComma->setChecked(true);
-    slotDelimiter(); // since the comma box was already checked, the slot won't fire
   } else if(m_delimiter == QLatin1String(";")) {
     m_radioSemicolon->setChecked(true);
   } else if(m_delimiter == QLatin1String("\t")) {
@@ -308,6 +340,7 @@ QWidget* CSVImporter::widget(QWidget* parent_) {
     m_editOther->setEnabled(true);
     m_editOther->setText(m_delimiter);
   }
+  slotDelimiter(); // initialize the parser and then load the text
 
   return m_widget;
 }
@@ -357,13 +390,13 @@ void CSVImporter::fillTable() {
 }
 
 void CSVImporter::slotTypeChanged() {
-  // iterate over the collection names until it matches the text of the combo box
-  Data::Collection::Type type = static_cast<Data::Collection::Type>(m_comboColl->currentType());
-  m_coll = CollectionFactory::collection(type, true);
+  createCollection();
 
   updateHeader(true);
   m_comboField->clear();
-  m_comboField->addItems(m_existingCollection ? m_existingCollection->fieldTitles() : m_coll->fieldTitles());
+  foreach(Data::FieldPtr field, m_coll->fields()) {
+    m_comboField->addItem(field->title());
+  }
   m_comboField->addItem(QLatin1Char('<') + i18n("New Field") + QLatin1Char('>'));
 
   // hack to force a resize
@@ -388,6 +421,8 @@ void CSVImporter::slotDelimiter() {
     m_editOther->setFocus();
     m_delimiter = m_editOther->text();
   }
+  m_colDelimiter = m_editColDelimiter->text();
+  m_rowDelimiter = m_editRowDelimiter->text();
   if(!m_delimiter.isEmpty()) {
     m_parser->setDelimiter(m_delimiter);
     fillTable();
@@ -396,18 +431,18 @@ void CSVImporter::slotDelimiter() {
 }
 
 void CSVImporter::slotCurrentChanged(int, int col_) {
-  int pos = col_+1;
+  const int pos = col_+1;
   m_colSpinBox->setValue(pos); //slotSelectColumn() gets called because of the signal
 }
 
 void CSVImporter::slotHeaderClicked(int col_) {
-  int pos = col_+1;
+  const int pos = col_+1;
   m_colSpinBox->setValue(pos); //slotSelectColumn() gets called because of the signal
 }
 
 void CSVImporter::slotSelectColumn(int pos_) {
   // pos is really the number of the position of the column
-  int col = pos_ - 1;
+  const int col = pos_ - 1;
   m_table->scrollToItem(m_table->item(0, col));
   m_comboField->setCurrentItem(m_table->horizontalHeaderItem(col)->text());
 }
@@ -446,15 +481,14 @@ void CSVImporter::updateHeader(bool force_) {
     return;
   }
 
-  Data::CollPtr currColl = m_existingCollection ? m_existingCollection : m_coll;
   for(int col = 0; col < m_table->columnCount(); ++col) {
     QTableWidgetItem* item = m_table->item(0, col);
     Data::FieldPtr field;
-    if(item && currColl) {
+    if(item && m_coll) {
       QString itemValue = item->text();
-      field = currColl->fieldByTitle(itemValue);
+      field = m_coll->fieldByTitle(itemValue);
       if(!field) {
-        field = currColl->fieldByName(itemValue);
+        field = m_coll->fieldByName(itemValue);
       }
     }
     QTableWidgetItem* headerItem = m_table->horizontalHeaderItem(col);
@@ -477,19 +511,20 @@ void CSVImporter::slotFieldChanged(int idx_) {
     return;
   }
 
-  Data::CollPtr c = m_existingCollection ? m_existingCollection : m_coll;
-  int count = c->fieldTitles().count();
-  CollectionFieldsDialog dlg(c, m_widget);
-//  dlg.setModal(true);
+  CollectionFieldsDialog dlg(m_coll, m_widget);
+  dlg.setNotifyKernel(false);
+
   if(dlg.exec() == QDialog::Accepted) {
     m_comboField->clear();
-    m_comboField->addItems(c->fieldTitles());
-    m_comboField->addItem(QLatin1Char('<') + i18n("New Field") + QLatin1Char('>'));
-    if(count != c->fieldTitles().count()) {
-      fillTable();
+    foreach(Data::FieldPtr field, m_coll->fields()) {
+      m_comboField->addItem(field->title());
     }
-    m_comboField->setCurrentIndex(0);
+    m_comboField->addItem(QLatin1Char('<') + i18n("New Field") + QLatin1Char('>'));
+    fillTable();
   }
+
+  // set the combo to the item before last
+  m_comboField->setCurrentIndex(m_comboField->count()-2);
 }
 
 void CSVImporter::slotActionChanged(int action_) {
@@ -526,4 +561,19 @@ void CSVImporter::slotCancel() {
   m_cancelled = true;
 }
 
+void CSVImporter::createCollection() {
+  Data::Collection::Type type = static_cast<Data::Collection::Type>(m_comboColl->currentType());
+  m_coll = CollectionFactory::collection(type, true);
+  if(m_existingCollection) {
+    // if we're using the existing collection, then we
+    // want the newly created collection to have the same fields
+    foreach(Data::FieldPtr field, m_coll->fields()) {
+      m_coll->removeField(field, true /* force */);
+    }
+    foreach(Data::FieldPtr field, m_existingCollection->fields()) {
+      m_coll->addField(Data::FieldPtr(new Data::Field(*field)));
+    }
+  }
+}
+
 #include "csvimporter.moc"
